# Table of contents

- [Welcome](README.md)
- [Celo Overview](overview.md)

## Getting Started

- [Choosing a Network](getting-started/choosing-a-network.md)
- [Mainnet](getting-started/mainnet.md)
  - [Running a Validator](getting-started/running-a-validator-in-mainnet.md)
  - [Running a Full Node](getting-started/running-a-full-node-in-mainnet.md)
- [Baklava Testnet](getting-started/baklava-testnet.md)
  - [Running a Validator](getting-started/running-a-validator-in-baklava.md)
  - [Running a Full Node](getting-started/running-a-full-node-in-baklava.md)
- [Alfajores Testnet](getting-started/alfajores-testnet.md)
  - [Using the Mobile Wallet](getting-started/using-the-mobile-wallet.md)
  - [Getting an Account and Funds](getting-started/faucet.md)
  - [Running a Full Node](getting-started/running-a-full-node-in-alfajores.md)
- [Hosted nodes](getting-started/hosted-nodes.md)
- [Validator Setup FAQ](getting-started/validator-troubleshooting-faq.md)
- [Glossary](GLOSSARY.md)

## CELO Owner Guide

- [Quick Start](celo-holder-guide/quick-start.md)
- [cUSD Owner Guide](celo-holder-guide/cusd.md)
- [Using a Ledger Wallet](celo-holder-guide/ledger.md)
- [Understanding ReleaseGold](celo-holder-guide/release-gold.md)
- [Voting for Validator Groups](celo-holder-guide/voting-validators.md)
- [Voting on Governance](celo-holder-guide/voting-governance.md)
- [Governance Cheat Sheet](celo-holder-guide/governance-cheat-sheet.md)
- [Recovering CELO from an Ethereum Address](celo-holder-guide/eth-recovery.md)
- [Recovering ETH from a Celo Address](celo-holder-guide/celo-recovery.md)

## Validator Guide

- [Overview](validator-guide/overview.md)
- [Attestation Service](validator-guide/attestation-service.md)
- [Key Management](validator-guide/key-management/summary.md)
  - [Detailed Role Descriptions](validator-guide/key-management/detailed.md)
  - [Validator Signer Key Rotation](validator-guide/key-management/key-rotation.md)
- [Securing Celo Nodes and Services](validator-guide/securing-nodes-and-services.md)
- [Monitoring](validator-guide/monitoring.md)
- [Devops Best Practices](validator-guide/devops-best-practices.md)
- [Upgrading a Node](validator-guide/node-upgrades.md)
- [Running Proxies](validator-guide/proxy.md)
- [Validator Explorer](validator-guide/validator-explorer.md)
- [Celo Foundation Voting Policy](validator-guide/celo-foundation-voting-policy.md)
- [Celo Signal](validator-guide/celo-signal.md)

## Developer Guide

- [Overview](developer-resources/overview.md)
- [Code Examples](developer-resources/start.md)
  - [Sending CELO & cUSD](developer-resources/walkthroughs/hellocelo.md)
  - [Deploy a Contract (local node)](developer-resources/walkthroughs/hellocontracts.md)
  - [Deploy and Interact with Contracts (Remotely)](developer-resources/walkthroughs/hello-contract-remote-node.md)
  - [DappKit Truffle Box](developer-resources/walkthroughs/hello-mobile-dapp.md)
  - [Using Windows](developer-resources/develop-on-windows.md)
  - [React based DApp](developer-resources/walkthroughs/web-dapp.md)
  <!-- - [Building a dApp with Contracts on Celo]() -->
  <!-- - [The Celo Protocol]()
    - [Architecture]()
    - [Similarities with Ethereum]()
    - [Difference between Ethereum and Celo]()
      - [Mobile First]()
      - [Architectural Differences]()
        - [Validators, full node, light node]()
      - [Protocol Differences]()
        - [TX object - link to transactions]()
        - [fees in dollars- link to Paying for Gas in Tokens]()
      - [Development Differences]()
    - [dApps on Celo]()
      - [What is a dApp?]() -->
    <!-- - [Architecture]() -->
- [ContractKit](developer-resources/contractkit/README.md)
  - [Setup](developer-resources/contractkit/setup.md)
  - [Using the kit](developer-resources/contractkit/usage.md)
  - [Using Web3 from the Kit](developer-resources/contractkit/notes-web3-with-contractkit.md)
  - [Celo Core Contracts. Wrappers / Registry](developer-resources/contractkit/contracts-wrappers-registry.md)
  - [Querying on-chain identifiers with ODIS](developer-resources/contractkit/odis.md)
  - [Migrating to ContractKit v1.0](developer-resources/contractkit/migrating-to-contractkit-v1.md)
    <!-- - [Example of querying (web3, kit)]()
    - [Example of sending tx (kit)]() -->
  <!-- - [Using Truffle]()
    - [Setting up a Local node]()
    - [Option: Using CeloProvider with Truffle]() -->
- [DAppKit](developer-resources/dappkit/README.md)
    <!-- - [Going mobile first (true decentralization)]()
    - [dApps and Wallets - Signing Transactions]() -->
  - [Setup](developer-resources/dappkit/setup.md)
    <!-- - [React Native]()
    - [Expo]() -->
  - [Usage](developer-resources/dappkit/usage.md)
  <!-- - [Guide to Asset Custody]() -->
- [Forno](developer-resources/forno/README.md)
- [Local Development Chain w/ Protocol Contracts](developer-resources/walkthroughs/development-chain.md)
- [Celo for Ethereum Developers](developer-resources/celo-for-eth-devs.md)
- [Celo DApp Gallery](developer-resources/celo-dapp-gallery.md)
- [Integrations](developer-resources/integrations/integrations.md)
  - [General](developer-resources/integrations/general.md)
  - [Checklist](developer-resources/integrations/checklist.md)
  - [Custody](developer-resources/integrations/custody.md)
  - [Listings](developer-resources/integrations/listings.md)
  - [Using a Cloud HSM](developer-resources/integrations/cloud-hsm.md)
- SDK Code Reference
  - [Base](developer-resources/base/reference/SUMMARY.md)
    <!-- base-reference-start -->
    - [Globals](developer-resources/base/reference/globals.md)
    - [Modules]()
      - [account](developer-resources/base/reference/modules/_account_.md)
      - [MnemonicLanguages](developer-resources/base/reference/enums/_account_.mnemoniclanguages.md)
      - [MnemonicStrength](developer-resources/base/reference/enums/_account_.mnemonicstrength.md)
      - [Bip39](developer-resources/base/reference/interfaces/_account_.bip39.md)
      - [address](developer-resources/base/reference/modules/_address_.md)
      - [async](developer-resources/base/reference/modules/_async_.md)
      - [attestations](developer-resources/base/reference/modules/_attestations_.md)
      - [IdentifierType](developer-resources/base/reference/enums/_attestations_.identifiertype.md)
      - [AttestationsStatus](developer-resources/base/reference/interfaces/_attestations_.attestationsstatus.md)
      - [collections](developer-resources/base/reference/modules/_collections_.md)
      - [AddressListItem](developer-resources/base/reference/interfaces/_collections_.addresslistitem.md)
      - [contacts](developer-resources/base/reference/modules/_contacts_.md)
      - [ContactPhoneNumber](developer-resources/base/reference/interfaces/_contacts_.contactphonenumber.md)
      - [MinimalContact](developer-resources/base/reference/interfaces/_contacts_.minimalcontact.md)
      - [currencies](developer-resources/base/reference/modules/_currencies_.md)
      - [CURRENCY_ENUM](developer-resources/base/reference/enums/_currencies_.currency_enum.md)
      - [SHORT_CURRENCIES](developer-resources/base/reference/enums/_currencies_.short_currencies.md)
      - [displayFormatting](developer-resources/base/reference/modules/_displayformatting_.md)
      - [future](developer-resources/base/reference/modules/_future_.md)
      - [Future](developer-resources/base/reference/classes/_future_.future.md)
      - [inputValidation](developer-resources/base/reference/modules/_inputvalidation_.md)
      - [ValidatorKind](developer-resources/base/reference/enums/_inputvalidation_.validatorkind.md)
      - [BaseProps](developer-resources/base/reference/interfaces/_inputvalidation_.baseprops.md)
      - [io](developer-resources/base/reference/modules/_io_.md)
      - [lock](developer-resources/base/reference/modules/_lock_.md)
      - [Lock](developer-resources/base/reference/classes/_lock_.lock.md)
      - [logger](developer-resources/base/reference/modules/_logger_.md)
      - [parsing](developer-resources/base/reference/modules/_parsing_.md)
      - [phoneNumbers](developer-resources/base/reference/modules/_phonenumbers_.md)
      - [ParsedPhoneNumber](developer-resources/base/reference/interfaces/_phonenumbers_.parsedphonenumber.md)
      - [result](developer-resources/base/reference/modules/_result_.md)
      - [JSONParseError](developer-resources/base/reference/classes/_result_.jsonparseerror.md)
      - [RootError](developer-resources/base/reference/classes/_result_.rooterror.md)
      - [BaseError](developer-resources/base/reference/interfaces/_result_.baseerror.md)
      - [ErrorResult](developer-resources/base/reference/interfaces/_result_.errorresult.md)
      - [OkResult](developer-resources/base/reference/interfaces/_result_.okresult.md)
      - [signatureUtils](developer-resources/base/reference/modules/_signatureutils_.md)
      - [Signature](developer-resources/base/reference/interfaces/_signatureutils_.signature.md)
      - [Signer](developer-resources/base/reference/interfaces/_signatureutils_.signer.md)
      - [string](developer-resources/base/reference/modules/_string_.md)
      - [task](developer-resources/base/reference/modules/_task_.md)
      - [RepeatTaskContext](developer-resources/base/reference/interfaces/_task_.repeattaskcontext.md)
      - [RetryTaskOptions](developer-resources/base/reference/interfaces/_task_.retrytaskoptions.md)
      - [RunningTask](developer-resources/base/reference/interfaces/_task_.runningtask.md)
      - [RunningTaskWithValue](developer-resources/base/reference/interfaces/_task_.runningtaskwithvalue.md)
      - [TaskOptions](developer-resources/base/reference/interfaces/_task_.taskoptions.md)
    - [Classes]()
      - [Future](developer-resources/base/reference/classes/_future_.future.md)
      - [Lock](developer-resources/base/reference/classes/_lock_.lock.md)
      - [JSONParseError](developer-resources/base/reference/classes/_result_.jsonparseerror.md)
      - [RootError](developer-resources/base/reference/classes/_result_.rooterror.md)
    - [Enums]()
      - [MnemonicLanguages](developer-resources/base/reference/enums/_account_.mnemoniclanguages.md)
      - [MnemonicStrength](developer-resources/base/reference/enums/_account_.mnemonicstrength.md)
      - [IdentifierType](developer-resources/base/reference/enums/_attestations_.identifiertype.md)
      - [CURRENCY_ENUM](developer-resources/base/reference/enums/_currencies_.currency_enum.md)
      - [SHORT_CURRENCIES](developer-resources/base/reference/enums/_currencies_.short_currencies.md)
      - [ValidatorKind](developer-resources/base/reference/enums/_inputvalidation_.validatorkind.md)
    - [Interfaces]()
      - [Bip39](developer-resources/base/reference/interfaces/_account_.bip39.md)
      - [AttestationsStatus](developer-resources/base/reference/interfaces/_attestations_.attestationsstatus.md)
      - [AddressListItem](developer-resources/base/reference/interfaces/_collections_.addresslistitem.md)
      - [ContactPhoneNumber](developer-resources/base/reference/interfaces/_contacts_.contactphonenumber.md)
      - [MinimalContact](developer-resources/base/reference/interfaces/_contacts_.minimalcontact.md)
      - [BaseProps](developer-resources/base/reference/interfaces/_inputvalidation_.baseprops.md)
      - [ParsedPhoneNumber](developer-resources/base/reference/interfaces/_phonenumbers_.parsedphonenumber.md)
      - [BaseError](developer-resources/base/reference/interfaces/_result_.baseerror.md)
      - [ErrorResult](developer-resources/base/reference/interfaces/_result_.errorresult.md)
      - [OkResult](developer-resources/base/reference/interfaces/_result_.okresult.md)
      - [Signature](developer-resources/base/reference/interfaces/_signatureutils_.signature.md)
      - [Signer](developer-resources/base/reference/interfaces/_signatureutils_.signer.md)
      - [RepeatTaskContext](developer-resources/base/reference/interfaces/_task_.repeattaskcontext.md)
      - [RetryTaskOptions](developer-resources/base/reference/interfaces/_task_.retrytaskoptions.md)
      - [RunningTask](developer-resources/base/reference/interfaces/_task_.runningtask.md)
      - [RunningTaskWithValue](developer-resources/base/reference/interfaces/_task_.runningtaskwithvalue.md)
      - [TaskOptions](developer-resources/base/reference/interfaces/_task_.taskoptions.md)
    <!-- base-reference-end -->

  - [Connect](developer-resources/connect/reference/SUMMARY.md)
    <!-- connect-reference-start -->
    - [Globals](developer-resources/connect/reference/globals.md)
    - [Modules]()
      - [abi-types](developer-resources/connect/reference/modules/_abi_types_.md)
      - [ABIDefinition](developer-resources/connect/reference/interfaces/_abi_types_.abidefinition.md)
      - [AbiCoder](developer-resources/connect/reference/interfaces/_abi_types_.abicoder.md)
      - [DecodedParamsArray](developer-resources/connect/reference/interfaces/_abi_types_.decodedparamsarray.md)
      - [DecodedParamsObject](developer-resources/connect/reference/interfaces/_abi_types_.decodedparamsobject.md)
      - [celo-provider](developer-resources/connect/reference/modules/_celo_provider_.md)
      - [CeloProvider](developer-resources/connect/reference/classes/_celo_provider_.celoprovider.md)
      - [connection](developer-resources/connect/reference/modules/_connection_.md)
      - [Connection](developer-resources/connect/reference/classes/_connection_.connection.md)
      - [ConnectionOptions](developer-resources/connect/reference/interfaces/_connection_.connectionoptions.md)
      - [types](developer-resources/connect/reference/modules/_types_.md)
      - [CeloParams](developer-resources/connect/reference/interfaces/_types_.celoparams.md)
      - [CeloTxObject](developer-resources/connect/reference/interfaces/_types_.celotxobject.md)
      - [EncodedTransaction](developer-resources/connect/reference/interfaces/_types_.encodedtransaction.md)
      - [JsonRpcPayload](developer-resources/connect/reference/interfaces/_types_.jsonrpcpayload.md)
      - [JsonRpcResponse](developer-resources/connect/reference/interfaces/_types_.jsonrpcresponse.md)
      - [Provider](developer-resources/connect/reference/interfaces/_types_.provider.md)
      - [RLPEncodedTx](developer-resources/connect/reference/interfaces/_types_.rlpencodedtx.md)
      - [utils/abi-utils](developer-resources/connect/reference/modules/_utils_abi_utils_.md)
      - [utils/celo-transaction-object](developer-resources/connect/reference/modules/_utils_celo_transaction_object_.md)
      - [CeloTransactionObject](developer-resources/connect/reference/classes/_utils_celo_transaction_object_.celotransactionobject.md)
      - [utils/formatter](developer-resources/connect/reference/modules/_utils_formatter_.md)
      - [utils/provider-utils](developer-resources/connect/reference/modules/_utils_provider_utils_.md)
      - [utils/rpc-caller](developer-resources/connect/reference/modules/_utils_rpc_caller_.md)
      - [DefaultRpcCaller](developer-resources/connect/reference/classes/_utils_rpc_caller_.defaultrpccaller.md)
      - [RpcCaller](developer-resources/connect/reference/interfaces/_utils_rpc_caller_.rpccaller.md)
      - [utils/tx-params-normalizer](developer-resources/connect/reference/modules/_utils_tx_params_normalizer_.md)
      - [TxParamsNormalizer](developer-resources/connect/reference/classes/_utils_tx_params_normalizer_.txparamsnormalizer.md)
      - [utils/tx-result](developer-resources/connect/reference/modules/_utils_tx_result_.md)
      - [TransactionResult](developer-resources/connect/reference/classes/_utils_tx_result_.transactionresult.md)
      - [wallet](developer-resources/connect/reference/modules/_wallet_.md)
      - [ReadOnlyWallet](developer-resources/connect/reference/interfaces/_wallet_.readonlywallet.md)
      - [Signer](developer-resources/connect/reference/interfaces/_wallet_.signer.md)
    - [Classes]()
      - [CeloProvider](developer-resources/connect/reference/classes/_celo_provider_.celoprovider.md)
      - [Connection](developer-resources/connect/reference/classes/_connection_.connection.md)
      - [CeloTransactionObject](developer-resources/connect/reference/classes/_utils_celo_transaction_object_.celotransactionobject.md)
      - [DefaultRpcCaller](developer-resources/connect/reference/classes/_utils_rpc_caller_.defaultrpccaller.md)
      - [TxParamsNormalizer](developer-resources/connect/reference/classes/_utils_tx_params_normalizer_.txparamsnormalizer.md)
      - [TransactionResult](developer-resources/connect/reference/classes/_utils_tx_result_.transactionresult.md)
    - [Interfaces]()
      - [ABIDefinition](developer-resources/connect/reference/interfaces/_abi_types_.abidefinition.md)
      - [AbiCoder](developer-resources/connect/reference/interfaces/_abi_types_.abicoder.md)
      - [DecodedParamsArray](developer-resources/connect/reference/interfaces/_abi_types_.decodedparamsarray.md)
      - [DecodedParamsObject](developer-resources/connect/reference/interfaces/_abi_types_.decodedparamsobject.md)
      - [ConnectionOptions](developer-resources/connect/reference/interfaces/_connection_.connectionoptions.md)
      - [CeloParams](developer-resources/connect/reference/interfaces/_types_.celoparams.md)
      - [CeloTxObject](developer-resources/connect/reference/interfaces/_types_.celotxobject.md)
      - [EncodedTransaction](developer-resources/connect/reference/interfaces/_types_.encodedtransaction.md)
      - [JsonRpcPayload](developer-resources/connect/reference/interfaces/_types_.jsonrpcpayload.md)
      - [JsonRpcResponse](developer-resources/connect/reference/interfaces/_types_.jsonrpcresponse.md)
      - [Provider](developer-resources/connect/reference/interfaces/_types_.provider.md)
      - [RLPEncodedTx](developer-resources/connect/reference/interfaces/_types_.rlpencodedtx.md)
      - [RpcCaller](developer-resources/connect/reference/interfaces/_utils_rpc_caller_.rpccaller.md)
      - [ReadOnlyWallet](developer-resources/connect/reference/interfaces/_wallet_.readonlywallet.md)
      - [Signer](developer-resources/connect/reference/interfaces/_wallet_.signer.md)
    <!-- connect-reference-end -->

  - [ContractKit](developer-resources/contractkit/reference/SUMMARY.md)
    <!-- contractkit-reference-start -->
    - [Globals](developer-resources/contractkit/reference/globals.md)
    - [Modules]()
      - [address-registry](developer-resources/contractkit/reference/modules/_address_registry_.md)
      - [AddressRegistry](developer-resources/contractkit/reference/classes/_address_registry_.addressregistry.md)
      - [base](developer-resources/contractkit/reference/modules/_base_.md)
      - [CeloContract](developer-resources/contractkit/reference/enums/_base_.celocontract.md)
      - [contract-cache](developer-resources/contractkit/reference/modules/_contract_cache_.md)
      - [WrapperCache](developer-resources/contractkit/reference/classes/_contract_cache_.wrappercache.md)
      - [identity/claims/account](developer-resources/contractkit/reference/modules/_identity_claims_account_.md)
      - [identity/claims/attestation-service-url](developer-resources/contractkit/reference/modules/_identity_claims_attestation_service_url_.md)
      - [identity/claims/claim](developer-resources/contractkit/reference/modules/_identity_claims_claim_.md)
      - [identity/claims/keybase](developer-resources/contractkit/reference/modules/_identity_claims_keybase_.md)
      - [identity/claims/types](developer-resources/contractkit/reference/modules/_identity_claims_types_.md)
      - [ClaimTypes](developer-resources/contractkit/reference/enums/_identity_claims_types_.claimtypes.md)
      - [identity/claims/verify](developer-resources/contractkit/reference/modules/_identity_claims_verify_.md)
      - [identity/metadata](developer-resources/contractkit/reference/modules/_identity_metadata_.md)
      - [IdentityMetadataWrapper](developer-resources/contractkit/reference/classes/_identity_metadata_.identitymetadatawrapper.md)
      - [kit](developer-resources/contractkit/reference/modules/_kit_.md)
      - [ContractKit](developer-resources/contractkit/reference/classes/_kit_.contractkit.md)
      - [NetworkConfig](developer-resources/contractkit/reference/interfaces/_kit_.networkconfig.md)
      - [proxy](developer-resources/contractkit/reference/modules/_proxy_.md)
      - [test-utils/PromiEventStub](developer-resources/contractkit/reference/modules/_test_utils_promieventstub_.md)
      - [test-utils/setup.global](developer-resources/contractkit/reference/modules/_test_utils_setup_global_.md)
      - [test-utils/teardown.global](developer-resources/contractkit/reference/modules/_test_utils_teardown_global_.md)
      - [web3-contract-cache](developer-resources/contractkit/reference/modules/_web3_contract_cache_.md)
      - [Web3ContractCache](developer-resources/contractkit/reference/classes/_web3_contract_cache_.web3contractcache.md)
      - [wrappers/Accounts](developer-resources/contractkit/reference/modules/_wrappers_accounts_.md)
      - [AccountsWrapper](developer-resources/contractkit/reference/classes/_wrappers_accounts_.accountswrapper.md)
      - [wrappers/Attestations](developer-resources/contractkit/reference/modules/_wrappers_attestations_.md)
      - [AttestationServiceStatusState](developer-resources/contractkit/reference/enums/_wrappers_attestations_.attestationservicestatusstate.md)
      - [AttestationState](developer-resources/contractkit/reference/enums/_wrappers_attestations_.attestationstate.md)
      - [AttestationsWrapper](developer-resources/contractkit/reference/classes/_wrappers_attestations_.attestationswrapper.md)
      - [ActionableAttestation](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.actionableattestation.md)
      - [AttestationServiceStatusResponse](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationservicestatusresponse.md)
      - [AttestationStat](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstat.md)
      - [AttestationStateForIssuer](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstateforissuer.md)
      - [AttestationsConfig](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationsconfig.md)
      - [AttestationsToken](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstoken.md)
      - [UnselectedRequest](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.unselectedrequest.md)
      - [wrappers/BaseSlasher](developer-resources/contractkit/reference/modules/_wrappers_baseslasher_.md)
      - [BaseSlasher](developer-resources/contractkit/reference/classes/_wrappers_baseslasher_.baseslasher.md)
      - [wrappers/BaseWrapper](developer-resources/contractkit/reference/modules/_wrappers_basewrapper_.md)
      - [BaseWrapper](developer-resources/contractkit/reference/classes/_wrappers_basewrapper_.basewrapper.md)
      - [wrappers/BlockchainParameters](developer-resources/contractkit/reference/modules/_wrappers_blockchainparameters_.md)
      - [BlockchainParametersWrapper](developer-resources/contractkit/reference/classes/_wrappers_blockchainparameters_.blockchainparameterswrapper.md)
      - [BlockchainParametersConfig](developer-resources/contractkit/reference/interfaces/_wrappers_blockchainparameters_.blockchainparametersconfig.md)
      - [ClientVersion](developer-resources/contractkit/reference/interfaces/_wrappers_blockchainparameters_.clientversion.md)
      - [wrappers/DoubleSigningSlasher](developer-resources/contractkit/reference/modules/_wrappers_doublesigningslasher_.md)
      - [DoubleSigningSlasherWrapper](developer-resources/contractkit/reference/classes/_wrappers_doublesigningslasher_.doublesigningslasherwrapper.md)
      - [wrappers/DowntimeSlasher](developer-resources/contractkit/reference/modules/_wrappers_downtimeslasher_.md)
      - [DowntimeSlasherWrapper](developer-resources/contractkit/reference/classes/_wrappers_downtimeslasher_.downtimeslasherwrapper.md)
      - [DowntimeSlasherConfig](developer-resources/contractkit/reference/interfaces/_wrappers_downtimeslasher_.downtimeslasherconfig.md)
      - [Interval](developer-resources/contractkit/reference/interfaces/_wrappers_downtimeslasher_.interval.md)
      - [wrappers/Election](developer-resources/contractkit/reference/modules/_wrappers_election_.md)
      - [ElectionWrapper](developer-resources/contractkit/reference/classes/_wrappers_election_.electionwrapper.md)
      - [ElectableValidators](developer-resources/contractkit/reference/interfaces/_wrappers_election_.electablevalidators.md)
      - [ElectionConfig](developer-resources/contractkit/reference/interfaces/_wrappers_election_.electionconfig.md)
      - [GroupVote](developer-resources/contractkit/reference/interfaces/_wrappers_election_.groupvote.md)
      - [GroupVoterReward](developer-resources/contractkit/reference/interfaces/_wrappers_election_.groupvoterreward.md)
      - [ValidatorGroupVote](developer-resources/contractkit/reference/interfaces/_wrappers_election_.validatorgroupvote.md)
      - [Voter](developer-resources/contractkit/reference/interfaces/_wrappers_election_.voter.md)
      - [VoterReward](developer-resources/contractkit/reference/interfaces/_wrappers_election_.voterreward.md)
      - [wrappers/Escrow](developer-resources/contractkit/reference/modules/_wrappers_escrow_.md)
      - [EscrowWrapper](developer-resources/contractkit/reference/classes/_wrappers_escrow_.escrowwrapper.md)
      - [wrappers/Exchange](developer-resources/contractkit/reference/modules/_wrappers_exchange_.md)
      - [ExchangeWrapper](developer-resources/contractkit/reference/classes/_wrappers_exchange_.exchangewrapper.md)
      - [ExchangeConfig](developer-resources/contractkit/reference/interfaces/_wrappers_exchange_.exchangeconfig.md)
      - [wrappers/Freezer](developer-resources/contractkit/reference/modules/_wrappers_freezer_.md)
      - [FreezerWrapper](developer-resources/contractkit/reference/classes/_wrappers_freezer_.freezerwrapper.md)
      - [wrappers/GasPriceMinimum](developer-resources/contractkit/reference/modules/_wrappers_gaspriceminimum_.md)
      - [GasPriceMinimumWrapper](developer-resources/contractkit/reference/classes/_wrappers_gaspriceminimum_.gaspriceminimumwrapper.md)
      - [GasPriceMinimumConfig](developer-resources/contractkit/reference/interfaces/_wrappers_gaspriceminimum_.gaspriceminimumconfig.md)
      - [wrappers/GoldTokenWrapper](developer-resources/contractkit/reference/modules/_wrappers_goldtokenwrapper_.md)
      - [GoldTokenWrapper](developer-resources/contractkit/reference/classes/_wrappers_goldtokenwrapper_.goldtokenwrapper.md)
      - [wrappers/Governance](developer-resources/contractkit/reference/modules/_wrappers_governance_.md)
      - [ProposalStage](developer-resources/contractkit/reference/enums/_wrappers_governance_.proposalstage.md)
      - [VoteValue](developer-resources/contractkit/reference/enums/_wrappers_governance_.votevalue.md)
      - [GovernanceWrapper](developer-resources/contractkit/reference/classes/_wrappers_governance_.governancewrapper.md)
      - [GovernanceConfig](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.governanceconfig.md)
      - [HotfixRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.hotfixrecord.md)
      - [ParticipationParameters](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.participationparameters.md)
      - [ProposalMetadata](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalmetadata.md)
      - [ProposalRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalrecord.md)
      - [ProposalStageDurations](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalstagedurations.md)
      - [UpvoteRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.upvoterecord.md)
      - [VoteRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.voterecord.md)
      - [Voter](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.voter.md)
      - [Votes](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.votes.md)
      - [wrappers/LockedGold](developer-resources/contractkit/reference/modules/_wrappers_lockedgold_.md)
      - [LockedGoldWrapper](developer-resources/contractkit/reference/classes/_wrappers_lockedgold_.lockedgoldwrapper.md)
      - [AccountSlashed](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.accountslashed.md)
      - [LockedGoldConfig](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.lockedgoldconfig.md)
      - [PendingWithdrawal](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.pendingwithdrawal.md)
      - [VotingDetails](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.votingdetails.md)
      - [wrappers/MetaTransactionWallet](developer-resources/contractkit/reference/modules/_wrappers_metatransactionwallet_.md)
      - [MetaTransactionWalletWrapper](developer-resources/contractkit/reference/classes/_wrappers_metatransactionwallet_.metatransactionwalletwrapper.md)
      - [RawTransaction](developer-resources/contractkit/reference/interfaces/_wrappers_metatransactionwallet_.rawtransaction.md)
      - [TransactionObjectWithValue](developer-resources/contractkit/reference/interfaces/_wrappers_metatransactionwallet_.transactionobjectwithvalue.md)
      - [wrappers/MetaTransactionWalletDeployer](developer-resources/contractkit/reference/modules/_wrappers_metatransactionwalletdeployer_.md)
      - [MetaTransactionWalletDeployerWrapper](developer-resources/contractkit/reference/classes/_wrappers_metatransactionwalletdeployer_.metatransactionwalletdeployerwrapper.md)
      - [wrappers/MultiSig](developer-resources/contractkit/reference/modules/_wrappers_multisig_.md)
      - [MultiSigWrapper](developer-resources/contractkit/reference/classes/_wrappers_multisig_.multisigwrapper.md)
      - [TransactionData](developer-resources/contractkit/reference/interfaces/_wrappers_multisig_.transactiondata.md)
      - [wrappers/ReleaseGold](developer-resources/contractkit/reference/modules/_wrappers_releasegold_.md)
      - [ReleaseGoldWrapper](developer-resources/contractkit/reference/classes/_wrappers_releasegold_.releasegoldwrapper.md)
      - [BalanceState](developer-resources/contractkit/reference/interfaces/_wrappers_releasegold_.balancestate.md)
      - [ReleaseGoldInfo](developer-resources/contractkit/reference/interfaces/_wrappers_releasegold_.releasegoldinfo.md)
      - [wrappers/Reserve](developer-resources/contractkit/reference/modules/_wrappers_reserve_.md)
      - [ReserveWrapper](developer-resources/contractkit/reference/classes/_wrappers_reserve_.reservewrapper.md)
      - [ReserveConfig](developer-resources/contractkit/reference/interfaces/_wrappers_reserve_.reserveconfig.md)
      - [wrappers/SortedOracles](developer-resources/contractkit/reference/modules/_wrappers_sortedoracles_.md)
      - [MedianRelation](developer-resources/contractkit/reference/enums/_wrappers_sortedoracles_.medianrelation.md)
      - [SortedOraclesWrapper](developer-resources/contractkit/reference/classes/_wrappers_sortedoracles_.sortedoracleswrapper.md)
      - [MedianRate](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.medianrate.md)
      - [OracleRate](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oraclerate.md)
      - [OracleReport](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oraclereport.md)
      - [OracleTimestamp](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oracletimestamp.md)
      - [SortedOraclesConfig](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.sortedoraclesconfig.md)
      - [wrappers/StableTokenWrapper](developer-resources/contractkit/reference/modules/_wrappers_stabletokenwrapper_.md)
      - [StableTokenWrapper](developer-resources/contractkit/reference/classes/_wrappers_stabletokenwrapper_.stabletokenwrapper.md)
      - [InflationParameters](developer-resources/contractkit/reference/interfaces/_wrappers_stabletokenwrapper_.inflationparameters.md)
      - [StableTokenConfig](developer-resources/contractkit/reference/interfaces/_wrappers_stabletokenwrapper_.stabletokenconfig.md)
      - [wrappers/Validators](developer-resources/contractkit/reference/modules/_wrappers_validators_.md)
      - [ValidatorsWrapper](developer-resources/contractkit/reference/classes/_wrappers_validators_.validatorswrapper.md)
      - [GroupMembership](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.groupmembership.md)
      - [LockedGoldRequirements](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.lockedgoldrequirements.md)
      - [MembershipHistoryExtraData](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.membershiphistoryextradata.md)
      - [Validator](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validator.md)
      - [ValidatorGroup](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorgroup.md)
      - [ValidatorReward](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorreward.md)
      - [ValidatorsConfig](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorsconfig.md)
    - [Classes]()
      - [AddressRegistry](developer-resources/contractkit/reference/classes/_address_registry_.addressregistry.md)
      - [WrapperCache](developer-resources/contractkit/reference/classes/_contract_cache_.wrappercache.md)
      - [IdentityMetadataWrapper](developer-resources/contractkit/reference/classes/_identity_metadata_.identitymetadatawrapper.md)
      - [ContractKit](developer-resources/contractkit/reference/classes/_kit_.contractkit.md)
      - [Web3ContractCache](developer-resources/contractkit/reference/classes/_web3_contract_cache_.web3contractcache.md)
      - [AccountsWrapper](developer-resources/contractkit/reference/classes/_wrappers_accounts_.accountswrapper.md)
      - [AttestationsWrapper](developer-resources/contractkit/reference/classes/_wrappers_attestations_.attestationswrapper.md)
      - [BaseSlasher](developer-resources/contractkit/reference/classes/_wrappers_baseslasher_.baseslasher.md)
      - [BaseWrapper](developer-resources/contractkit/reference/classes/_wrappers_basewrapper_.basewrapper.md)
      - [BlockchainParametersWrapper](developer-resources/contractkit/reference/classes/_wrappers_blockchainparameters_.blockchainparameterswrapper.md)
      - [DoubleSigningSlasherWrapper](developer-resources/contractkit/reference/classes/_wrappers_doublesigningslasher_.doublesigningslasherwrapper.md)
      - [DowntimeSlasherWrapper](developer-resources/contractkit/reference/classes/_wrappers_downtimeslasher_.downtimeslasherwrapper.md)
      - [ElectionWrapper](developer-resources/contractkit/reference/classes/_wrappers_election_.electionwrapper.md)
      - [EscrowWrapper](developer-resources/contractkit/reference/classes/_wrappers_escrow_.escrowwrapper.md)
      - [ExchangeWrapper](developer-resources/contractkit/reference/classes/_wrappers_exchange_.exchangewrapper.md)
      - [FreezerWrapper](developer-resources/contractkit/reference/classes/_wrappers_freezer_.freezerwrapper.md)
      - [GasPriceMinimumWrapper](developer-resources/contractkit/reference/classes/_wrappers_gaspriceminimum_.gaspriceminimumwrapper.md)
      - [GoldTokenWrapper](developer-resources/contractkit/reference/classes/_wrappers_goldtokenwrapper_.goldtokenwrapper.md)
      - [GovernanceWrapper](developer-resources/contractkit/reference/classes/_wrappers_governance_.governancewrapper.md)
      - [LockedGoldWrapper](developer-resources/contractkit/reference/classes/_wrappers_lockedgold_.lockedgoldwrapper.md)
      - [MetaTransactionWalletWrapper](developer-resources/contractkit/reference/classes/_wrappers_metatransactionwallet_.metatransactionwalletwrapper.md)
      - [MetaTransactionWalletDeployerWrapper](developer-resources/contractkit/reference/classes/_wrappers_metatransactionwalletdeployer_.metatransactionwalletdeployerwrapper.md)
      - [MultiSigWrapper](developer-resources/contractkit/reference/classes/_wrappers_multisig_.multisigwrapper.md)
      - [ReleaseGoldWrapper](developer-resources/contractkit/reference/classes/_wrappers_releasegold_.releasegoldwrapper.md)
      - [ReserveWrapper](developer-resources/contractkit/reference/classes/_wrappers_reserve_.reservewrapper.md)
      - [SortedOraclesWrapper](developer-resources/contractkit/reference/classes/_wrappers_sortedoracles_.sortedoracleswrapper.md)
      - [StableTokenWrapper](developer-resources/contractkit/reference/classes/_wrappers_stabletokenwrapper_.stabletokenwrapper.md)
      - [ValidatorsWrapper](developer-resources/contractkit/reference/classes/_wrappers_validators_.validatorswrapper.md)
    - [Enums]()
      - [CeloContract](developer-resources/contractkit/reference/enums/_base_.celocontract.md)
      - [ClaimTypes](developer-resources/contractkit/reference/enums/_identity_claims_types_.claimtypes.md)
      - [AttestationServiceStatusState](developer-resources/contractkit/reference/enums/_wrappers_attestations_.attestationservicestatusstate.md)
      - [AttestationState](developer-resources/contractkit/reference/enums/_wrappers_attestations_.attestationstate.md)
      - [ProposalStage](developer-resources/contractkit/reference/enums/_wrappers_governance_.proposalstage.md)
      - [VoteValue](developer-resources/contractkit/reference/enums/_wrappers_governance_.votevalue.md)
      - [MedianRelation](developer-resources/contractkit/reference/enums/_wrappers_sortedoracles_.medianrelation.md)
    - [Interfaces]()
      - [NetworkConfig](developer-resources/contractkit/reference/interfaces/_kit_.networkconfig.md)
      - [ActionableAttestation](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.actionableattestation.md)
      - [AttestationServiceStatusResponse](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationservicestatusresponse.md)
      - [AttestationStat](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstat.md)
      - [AttestationStateForIssuer](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstateforissuer.md)
      - [AttestationsConfig](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationsconfig.md)
      - [AttestationsToken](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.attestationstoken.md)
      - [UnselectedRequest](developer-resources/contractkit/reference/interfaces/_wrappers_attestations_.unselectedrequest.md)
      - [BlockchainParametersConfig](developer-resources/contractkit/reference/interfaces/_wrappers_blockchainparameters_.blockchainparametersconfig.md)
      - [ClientVersion](developer-resources/contractkit/reference/interfaces/_wrappers_blockchainparameters_.clientversion.md)
      - [DowntimeSlasherConfig](developer-resources/contractkit/reference/interfaces/_wrappers_downtimeslasher_.downtimeslasherconfig.md)
      - [Interval](developer-resources/contractkit/reference/interfaces/_wrappers_downtimeslasher_.interval.md)
      - [ElectableValidators](developer-resources/contractkit/reference/interfaces/_wrappers_election_.electablevalidators.md)
      - [ElectionConfig](developer-resources/contractkit/reference/interfaces/_wrappers_election_.electionconfig.md)
      - [GroupVote](developer-resources/contractkit/reference/interfaces/_wrappers_election_.groupvote.md)
      - [GroupVoterReward](developer-resources/contractkit/reference/interfaces/_wrappers_election_.groupvoterreward.md)
      - [ValidatorGroupVote](developer-resources/contractkit/reference/interfaces/_wrappers_election_.validatorgroupvote.md)
      - [Voter](developer-resources/contractkit/reference/interfaces/_wrappers_election_.voter.md)
      - [VoterReward](developer-resources/contractkit/reference/interfaces/_wrappers_election_.voterreward.md)
      - [ExchangeConfig](developer-resources/contractkit/reference/interfaces/_wrappers_exchange_.exchangeconfig.md)
      - [GasPriceMinimumConfig](developer-resources/contractkit/reference/interfaces/_wrappers_gaspriceminimum_.gaspriceminimumconfig.md)
      - [GovernanceConfig](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.governanceconfig.md)
      - [HotfixRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.hotfixrecord.md)
      - [ParticipationParameters](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.participationparameters.md)
      - [ProposalMetadata](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalmetadata.md)
      - [ProposalRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalrecord.md)
      - [ProposalStageDurations](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.proposalstagedurations.md)
      - [UpvoteRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.upvoterecord.md)
      - [VoteRecord](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.voterecord.md)
      - [Voter](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.voter.md)
      - [Votes](developer-resources/contractkit/reference/interfaces/_wrappers_governance_.votes.md)
      - [AccountSlashed](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.accountslashed.md)
      - [LockedGoldConfig](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.lockedgoldconfig.md)
      - [PendingWithdrawal](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.pendingwithdrawal.md)
      - [VotingDetails](developer-resources/contractkit/reference/interfaces/_wrappers_lockedgold_.votingdetails.md)
      - [RawTransaction](developer-resources/contractkit/reference/interfaces/_wrappers_metatransactionwallet_.rawtransaction.md)
      - [TransactionObjectWithValue](developer-resources/contractkit/reference/interfaces/_wrappers_metatransactionwallet_.transactionobjectwithvalue.md)
      - [TransactionData](developer-resources/contractkit/reference/interfaces/_wrappers_multisig_.transactiondata.md)
      - [BalanceState](developer-resources/contractkit/reference/interfaces/_wrappers_releasegold_.balancestate.md)
      - [ReleaseGoldInfo](developer-resources/contractkit/reference/interfaces/_wrappers_releasegold_.releasegoldinfo.md)
      - [ReserveConfig](developer-resources/contractkit/reference/interfaces/_wrappers_reserve_.reserveconfig.md)
      - [MedianRate](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.medianrate.md)
      - [OracleRate](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oraclerate.md)
      - [OracleReport](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oraclereport.md)
      - [OracleTimestamp](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.oracletimestamp.md)
      - [SortedOraclesConfig](developer-resources/contractkit/reference/interfaces/_wrappers_sortedoracles_.sortedoraclesconfig.md)
      - [InflationParameters](developer-resources/contractkit/reference/interfaces/_wrappers_stabletokenwrapper_.inflationparameters.md)
      - [StableTokenConfig](developer-resources/contractkit/reference/interfaces/_wrappers_stabletokenwrapper_.stabletokenconfig.md)
      - [GroupMembership](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.groupmembership.md)
      - [LockedGoldRequirements](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.lockedgoldrequirements.md)
      - [MembershipHistoryExtraData](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.membershiphistoryextradata.md)
      - [Validator](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validator.md)
      - [ValidatorGroup](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorgroup.md)
      - [ValidatorReward](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorreward.md)
      - [ValidatorsConfig](developer-resources/contractkit/reference/interfaces/_wrappers_validators_.validatorsconfig.md)
    <!-- contractkit-reference-end -->

  - [Explorer](developer-resources/explorer/reference/SUMMARY.md)
    <!-- explorer-reference-start -->
    - [Globals](developer-resources/explorer/reference/globals.md)
    - [Modules]()
      - [base](developer-resources/explorer/reference/modules/_base_.md)
      - [ContractDetails](developer-resources/explorer/reference/interfaces/_base_.contractdetails.md)
      - [block-explorer](developer-resources/explorer/reference/modules/_block_explorer_.md)
      - [BlockExplorer](developer-resources/explorer/reference/classes/_block_explorer_.blockexplorer.md)
      - [CallDetails](developer-resources/explorer/reference/interfaces/_block_explorer_.calldetails.md)
      - [ParsedBlock](developer-resources/explorer/reference/interfaces/_block_explorer_.parsedblock.md)
      - [ParsedTx](developer-resources/explorer/reference/interfaces/_block_explorer_.parsedtx.md)
      - [log-explorer](developer-resources/explorer/reference/modules/_log_explorer_.md)
      - [LogExplorer](developer-resources/explorer/reference/classes/_log_explorer_.logexplorer.md)
    - [Classes]()
      - [BlockExplorer](developer-resources/explorer/reference/classes/_block_explorer_.blockexplorer.md)
      - [LogExplorer](developer-resources/explorer/reference/classes/_log_explorer_.logexplorer.md)
    - [Interfaces]()
      - [ContractDetails](developer-resources/explorer/reference/interfaces/_base_.contractdetails.md)
      - [CallDetails](developer-resources/explorer/reference/interfaces/_block_explorer_.calldetails.md)
      - [ParsedBlock](developer-resources/explorer/reference/interfaces/_block_explorer_.parsedblock.md)
      - [ParsedTx](developer-resources/explorer/reference/interfaces/_block_explorer_.parsedtx.md)
    <!-- explorer-reference-end -->
  
  - [Governance](developer-resources/governance/reference/SUMMARY.md)
    <!-- governance-reference-start -->
    - [Globals](developer-resources/governance/reference/globals.md)
    - [Modules]()
      - [proposals](developer-resources/governance/reference/modules/_proposals_.md)
      - [InteractiveProposalBuilder](developer-resources/governance/reference/classes/_proposals_.interactiveproposalbuilder.md)
      - [ProposalBuilder](developer-resources/governance/reference/classes/_proposals_.proposalbuilder.md)
      - [ProposalTransactionJSON](developer-resources/governance/reference/interfaces/_proposals_.proposaltransactionjson.md)
    - [Classes]()
      - [InteractiveProposalBuilder](developer-resources/governance/reference/classes/_proposals_.interactiveproposalbuilder.md)
      - [ProposalBuilder](developer-resources/governance/reference/classes/_proposals_.proposalbuilder.md)
    - [Interfaces]()
      - [ProposalTransactionJSON](developer-resources/governance/reference/interfaces/_proposals_.proposaltransactionjson.md)
    <!-- governance-reference-end -->

  - [Identity](developer-resources/identity/reference/SUMMARY.md)
    <!-- identity-reference-start -->
    - [Globals](developer-resources/identity/reference/globals.md)
    - [Modules]()
      - [odis/bls-blinding-client](developer-resources/identity/reference/modules/_odis_bls_blinding_client_.md)
      - [WasmBlsBlindingClient](developer-resources/identity/reference/classes/_odis_bls_blinding_client_.wasmblsblindingclient.md)
      - [BlsBlindingClient](developer-resources/identity/reference/interfaces/_odis_bls_blinding_client_.blsblindingclient.md)
      - [odis/matchmaking](developer-resources/identity/reference/modules/_odis_matchmaking_.md)
      - [odis/phone-number-identifier](developer-resources/identity/reference/modules/_odis_phone_number_identifier_.md)
      - [PhoneNumberHashDetails](developer-resources/identity/reference/interfaces/_odis_phone_number_identifier_.phonenumberhashdetails.md)
      - [odis/query](developer-resources/identity/reference/modules/_odis_query_.md)
      - [AuthenticationMethod](developer-resources/identity/reference/enums/_odis_query_.authenticationmethod.md)
      - [ErrorMessages](developer-resources/identity/reference/enums/_odis_query_.errormessages.md)
      - [CustomSigner](developer-resources/identity/reference/interfaces/_odis_query_.customsigner.md)
      - [EncryptionKeySigner](developer-resources/identity/reference/interfaces/_odis_query_.encryptionkeysigner.md)
      - [MatchmakingRequest](developer-resources/identity/reference/interfaces/_odis_query_.matchmakingrequest.md)
      - [MatchmakingResponse](developer-resources/identity/reference/interfaces/_odis_query_.matchmakingresponse.md)
      - [PhoneNumberPrivacyRequest](developer-resources/identity/reference/interfaces/_odis_query_.phonenumberprivacyrequest.md)
      - [ServiceContext](developer-resources/identity/reference/interfaces/_odis_query_.servicecontext.md)
      - [SignMessageRequest](developer-resources/identity/reference/interfaces/_odis_query_.signmessagerequest.md)
      - [SignMessageResponse](developer-resources/identity/reference/interfaces/_odis_query_.signmessageresponse.md)
      - [WalletKeySigner](developer-resources/identity/reference/interfaces/_odis_query_.walletkeysigner.md)
      - [offchain-data-wrapper](developer-resources/identity/reference/modules/_offchain_data_wrapper_.md)
      - [OffchainErrorTypes](developer-resources/identity/reference/enums/_offchain_data_wrapper_.offchainerrortypes.md)
      - [OffchainDataWrapper](developer-resources/identity/reference/classes/_offchain_data_wrapper_.offchaindatawrapper.md)
      - [offchain/accessors/authorized-signer](developer-resources/identity/reference/modules/_offchain_accessors_authorized_signer_.md)
      - [AuthorizedSignerAccessor](developer-resources/identity/reference/classes/_offchain_accessors_authorized_signer_.authorizedsigneraccessor.md)
      - [offchain/accessors/binary](developer-resources/identity/reference/modules/_offchain_accessors_binary_.md)
      - [PrivateBinaryAccessor](developer-resources/identity/reference/classes/_offchain_accessors_binary_.privatebinaryaccessor.md)
      - [PublicBinaryAccessor](developer-resources/identity/reference/classes/_offchain_accessors_binary_.publicbinaryaccessor.md)
      - [offchain/accessors/errors](developer-resources/identity/reference/modules/_offchain_accessors_errors_.md)
      - [SchemaErrorTypes](developer-resources/identity/reference/enums/_offchain_accessors_errors_.schemaerrortypes.md)
      - [InvalidDataError](developer-resources/identity/reference/classes/_offchain_accessors_errors_.invaliddataerror.md)
      - [InvalidKey](developer-resources/identity/reference/classes/_offchain_accessors_errors_.invalidkey.md)
      - [OffchainError](developer-resources/identity/reference/classes/_offchain_accessors_errors_.offchainerror.md)
      - [UnavailableKey](developer-resources/identity/reference/classes/_offchain_accessors_errors_.unavailablekey.md)
      - [UnknownCiphertext](developer-resources/identity/reference/classes/_offchain_accessors_errors_.unknownciphertext.md)
      - [offchain/accessors/interfaces](developer-resources/identity/reference/modules/_offchain_accessors_interfaces_.md)
      - [PrivateAccessor](developer-resources/identity/reference/interfaces/_offchain_accessors_interfaces_.privateaccessor.md)
      - [PublicAccessor](developer-resources/identity/reference/interfaces/_offchain_accessors_interfaces_.publicaccessor.md)
      - [offchain/accessors/name](developer-resources/identity/reference/modules/_offchain_accessors_name_.md)
      - [PrivateNameAccessor](developer-resources/identity/reference/classes/_offchain_accessors_name_.privatenameaccessor.md)
      - [PublicNameAccessor](developer-resources/identity/reference/classes/_offchain_accessors_name_.publicnameaccessor.md)
      - [offchain/accessors/pictures](developer-resources/identity/reference/modules/_offchain_accessors_pictures_.md)
      - [PrivatePictureAccessor](developer-resources/identity/reference/classes/_offchain_accessors_pictures_.privatepictureaccessor.md)
      - [PublicPictureAccessor](developer-resources/identity/reference/classes/_offchain_accessors_pictures_.publicpictureaccessor.md)
      - [offchain/accessors/simple](developer-resources/identity/reference/modules/_offchain_accessors_simple_.md)
      - [PrivateSimpleAccessor](developer-resources/identity/reference/classes/_offchain_accessors_simple_.privatesimpleaccessor.md)
      - [PublicSimpleAccessor](developer-resources/identity/reference/classes/_offchain_accessors_simple_.publicsimpleaccessor.md)
      - [offchain/storage-writers](developer-resources/identity/reference/modules/_offchain_storage_writers_.md)
      - [GitStorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.gitstoragewriter.md)
      - [GoogleStorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.googlestoragewriter.md)
      - [LocalStorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.localstoragewriter.md)
      - [MockStorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.mockstoragewriter.md)
      - [StorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.storagewriter.md)
      - [offchain/utils](developer-resources/identity/reference/modules/_offchain_utils_.md)
      - [test-utils/setup.global](developer-resources/identity/reference/modules/_test_utils_setup_global_.md)
      - [test-utils/teardown.global](developer-resources/identity/reference/modules/_test_utils_teardown_global_.md)
    - [Classes]()
      - [WasmBlsBlindingClient](developer-resources/identity/reference/classes/_odis_bls_blinding_client_.wasmblsblindingclient.md)
      - [OffchainDataWrapper](developer-resources/identity/reference/classes/_offchain_data_wrapper_.offchaindatawrapper.md)
      - [AuthorizedSignerAccessor](developer-resources/identity/reference/classes/_offchain_accessors_authorized_signer_.authorizedsigneraccessor.md)
      - [PrivateBinaryAccessor](developer-resources/identity/reference/classes/_offchain_accessors_binary_.privatebinaryaccessor.md)
      - [PublicBinaryAccessor](developer-resources/identity/reference/classes/_offchain_accessors_binary_.publicbinaryaccessor.md)
      - [InvalidDataError](developer-resources/identity/reference/classes/_offchain_accessors_errors_.invaliddataerror.md)
      - [InvalidKey](developer-resources/identity/reference/classes/_offchain_accessors_errors_.invalidkey.md)
      - [OffchainError](developer-resources/identity/reference/classes/_offchain_accessors_errors_.offchainerror.md)
      - [UnavailableKey](developer-resources/identity/reference/classes/_offchain_accessors_errors_.unavailablekey.md)
      - [UnknownCiphertext](developer-resources/identity/reference/classes/_offchain_accessors_errors_.unknownciphertext.md)
      - [PrivateNameAccessor](developer-resources/identity/reference/classes/_offchain_accessors_name_.privatenameaccessor.md)
      - [PublicNameAccessor](developer-resources/identity/reference/classes/_offchain_accessors_name_.publicnameaccessor.md)
      - [PrivatePictureAccessor](developer-resources/identity/reference/classes/_offchain_accessors_pictures_.privatepictureaccessor.md)
      - [PublicPictureAccessor](developer-resources/identity/reference/classes/_offchain_accessors_pictures_.publicpictureaccessor.md)
      - [PrivateSimpleAccessor](developer-resources/identity/reference/classes/_offchain_accessors_simple_.privatesimpleaccessor.md)
      - [PublicSimpleAccessor](developer-resources/identity/reference/classes/_offchain_accessors_simple_.publicsimpleaccessor.md)
      - [GitStorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.gitstoragewriter.md)
      - [GoogleStorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.googlestoragewriter.md)
      - [LocalStorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.localstoragewriter.md)
      - [MockStorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.mockstoragewriter.md)
      - [StorageWriter](developer-resources/identity/reference/classes/_offchain_storage_writers_.storagewriter.md)
    - [Enums]()
      - [AuthenticationMethod](developer-resources/identity/reference/enums/_odis_query_.authenticationmethod.md)
      - [ErrorMessages](developer-resources/identity/reference/enums/_odis_query_.errormessages.md)
      - [OffchainErrorTypes](developer-resources/identity/reference/enums/_offchain_data_wrapper_.offchainerrortypes.md)
      - [SchemaErrorTypes](developer-resources/identity/reference/enums/_offchain_accessors_errors_.schemaerrortypes.md)
    - [Interfaces]()
      - [BlsBlindingClient](developer-resources/identity/reference/interfaces/_odis_bls_blinding_client_.blsblindingclient.md)
      - [PhoneNumberHashDetails](developer-resources/identity/reference/interfaces/_odis_phone_number_identifier_.phonenumberhashdetails.md)
      - [CustomSigner](developer-resources/identity/reference/interfaces/_odis_query_.customsigner.md)
      - [EncryptionKeySigner](developer-resources/identity/reference/interfaces/_odis_query_.encryptionkeysigner.md)
      - [MatchmakingRequest](developer-resources/identity/reference/interfaces/_odis_query_.matchmakingrequest.md)
      - [MatchmakingResponse](developer-resources/identity/reference/interfaces/_odis_query_.matchmakingresponse.md)
      - [PhoneNumberPrivacyRequest](developer-resources/identity/reference/interfaces/_odis_query_.phonenumberprivacyrequest.md)
      - [ServiceContext](developer-resources/identity/reference/interfaces/_odis_query_.servicecontext.md)
      - [SignMessageRequest](developer-resources/identity/reference/interfaces/_odis_query_.signmessagerequest.md)
      - [SignMessageResponse](developer-resources/identity/reference/interfaces/_odis_query_.signmessageresponse.md)
      - [WalletKeySigner](developer-resources/identity/reference/interfaces/_odis_query_.walletkeysigner.md)
      - [PrivateAccessor](developer-resources/identity/reference/interfaces/_offchain_accessors_interfaces_.privateaccessor.md)
      - [PublicAccessor](developer-resources/identity/reference/interfaces/_offchain_accessors_interfaces_.publicaccessor.md)
    <!-- identity-reference-end -->

  - [Network-Utils](developer-resources/network-utils/reference/SUMMARY.md)
    <!-- network-utils-reference-start -->
    - [Globals](developer-resources/network-utils/reference/globals.md)
    - [Modules]()
      - [genesis-block-utils](developer-resources/network-utils/reference/modules/_genesis_block_utils_.md)
      - [GenesisBlockUtils](developer-resources/network-utils/reference/classes/_genesis_block_utils_.genesisblockutils.md)
      - [google-storage-utils](developer-resources/network-utils/reference/modules/_google_storage_utils_.md)
      - [GoogleStorageUtils](developer-resources/network-utils/reference/classes/_google_storage_utils_.googlestorageutils.md)
      - [static-node-utils](developer-resources/network-utils/reference/modules/_static_node_utils_.md)
      - [StaticNodeUtils](developer-resources/network-utils/reference/classes/_static_node_utils_.staticnodeutils.md)
      - [utils/timezone](developer-resources/network-utils/reference/modules/_utils_timezone_.md)
      - [Coordinates](developer-resources/network-utils/reference/interfaces/_utils_timezone_.coordinates.md)
      - [Timezone](developer-resources/network-utils/reference/interfaces/_utils_timezone_.timezone.md)
    - [Classes]()
      - [GenesisBlockUtils](developer-resources/network-utils/reference/classes/_genesis_block_utils_.genesisblockutils.md)
      - [GoogleStorageUtils](developer-resources/network-utils/reference/classes/_google_storage_utils_.googlestorageutils.md)
      - [StaticNodeUtils](developer-resources/network-utils/reference/classes/_static_node_utils_.staticnodeutils.md)
    - [Interfaces]()
      - [Coordinates](developer-resources/network-utils/reference/interfaces/_utils_timezone_.coordinates.md)
      - [Timezone](developer-resources/network-utils/reference/interfaces/_utils_timezone_.timezone.md)
    <!-- network-utils-reference-end -->

  - [Transactions-Uri](developer-resources/transactions-uri/reference/SUMMARY.md)
    <!-- transactions-uri-reference-start -->
    - [Globals](developer-resources/transactions-uri/reference/globals.md)
    - [Modules]()
      - [test-utils/setup.global](developer-resources/transactions-uri/reference/modules/_test_utils_setup_global_.md)
      - [test-utils/teardown.global](developer-resources/transactions-uri/reference/modules/_test_utils_teardown_global_.md)
      - [tx-uri](developer-resources/transactions-uri/reference/modules/_tx_uri_.md)
    <!-- transactions-uri-reference-end -->

  - [Utils](developer-resources/utils/reference/SUMMARY.md)
    <!-- utils-reference-start -->
    - [Globals](developer-resources/utils/reference/globals.md)
    - [Modules]()
      - [node_modules/bls12377js/src/bls](developer-resources/utils/reference/modules/_node_modules_bls12377js_src_bls_.md)
      - [node_modules/bls12377js/src/defs](developer-resources/utils/reference/modules/_node_modules_bls12377js_src_defs_.md)
      - [FieldSpec](developer-resources/utils/reference/interfaces/_node_modules_bls12377js_src_defs_.fieldspec.md)
      - [GroupSpec](developer-resources/utils/reference/interfaces/_node_modules_bls12377js_src_defs_.groupspec.md)
      - [node_modules/bls12377js/src/f](developer-resources/utils/reference/modules/_node_modules_bls12377js_src_f_.md)
      - [F](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_f_.f.md)
      - [node_modules/bls12377js/src/f2](developer-resources/utils/reference/modules/_node_modules_bls12377js_src_f2_.md)
      - [F2](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_f2_.f2.md)
      - [node_modules/bls12377js/src/g1](developer-resources/utils/reference/modules/_node_modules_bls12377js_src_g1_.md)
      - [G1](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_g1_.g1.md)
      - [node_modules/bls12377js/src/g2](developer-resources/utils/reference/modules/_node_modules_bls12377js_src_g2_.md)
      - [G2](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_g2_.g2.md)
      - [node_modules/bls12377js/src/group](developer-resources/utils/reference/modules/_node_modules_bls12377js_src_group_.md)
      - [Group](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_group_.group.md)
      - [packages/sdk/utils/src/account](developer-resources/utils/reference/modules/_packages_sdk_utils_src_account_.md)
      - [packages/sdk/utils/src/address](developer-resources/utils/reference/modules/_packages_sdk_utils_src_address_.md)
      - [packages/sdk/utils/src/async](developer-resources/utils/reference/modules/_packages_sdk_utils_src_async_.md)
      - [packages/sdk/utils/src/attestations](developer-resources/utils/reference/modules/_packages_sdk_utils_src_attestations_.md)
      - [packages/sdk/utils/src/bls](developer-resources/utils/reference/modules/_packages_sdk_utils_src_bls_.md)
      - [packages/sdk/utils/src/bn](developer-resources/utils/reference/modules/_packages_sdk_utils_src_bn_.md)
      - [packages/sdk/utils/src/celoHistory](developer-resources/utils/reference/modules/_packages_sdk_utils_src_celohistory_.md)
      - [packages/sdk/utils/src/collections](developer-resources/utils/reference/modules/_packages_sdk_utils_src_collections_.md)
      - [packages/sdk/utils/src/commentEncryption](developer-resources/utils/reference/modules/_packages_sdk_utils_src_commentencryption_.md)
      - [EncryptionStatus](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_commentencryption_.encryptionstatus.md)
      - [packages/sdk/utils/src/contacts](developer-resources/utils/reference/modules/_packages_sdk_utils_src_contacts_.md)
      - [packages/sdk/utils/src/countries](developer-resources/utils/reference/modules/_packages_sdk_utils_src_countries_.md)
      - [Countries](developer-resources/utils/reference/classes/_packages_sdk_utils_src_countries_.countries.md)
      - [LocalizedCountry](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_countries_.localizedcountry.md)
      - [packages/sdk/utils/src/currencies](developer-resources/utils/reference/modules/_packages_sdk_utils_src_currencies_.md)
      - [packages/sdk/utils/src/dappkit](developer-resources/utils/reference/modules/_packages_sdk_utils_src_dappkit_.md)
      - [DappKitRequestTypes](developer-resources/utils/reference/enums/_packages_sdk_utils_src_dappkit_.dappkitrequesttypes.md)
      - [DappKitResponseStatus](developer-resources/utils/reference/enums/_packages_sdk_utils_src_dappkit_.dappkitresponsestatus.md)
      - [AccountAuthRequest](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.accountauthrequest.md)
      - [AccountAuthResponseFailure](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.accountauthresponsefailure.md)
      - [AccountAuthResponseSuccess](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.accountauthresponsesuccess.md)
      - [DappKitRequestBase](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.dappkitrequestbase.md)
      - [DappKitRequestMeta](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.dappkitrequestmeta.md)
      - [SignTxRequest](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.signtxrequest.md)
      - [SignTxResponseFailure](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.signtxresponsefailure.md)
      - [SignTxResponseSuccess](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.signtxresponsesuccess.md)
      - [TxToSignParam](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.txtosignparam.md)
      - [packages/sdk/utils/src/dataEncryptionKey](developer-resources/utils/reference/modules/_packages_sdk_utils_src_dataencryptionkey_.md)
      - [packages/sdk/utils/src/displayFormatting](developer-resources/utils/reference/modules/_packages_sdk_utils_src_displayformatting_.md)
      - [packages/sdk/utils/src/ecdh](developer-resources/utils/reference/modules/_packages_sdk_utils_src_ecdh_.md)
      - [packages/sdk/utils/src/ecies](developer-resources/utils/reference/modules/_packages_sdk_utils_src_ecies_.md)
      - [packages/sdk/utils/src/fixidity](developer-resources/utils/reference/modules/_packages_sdk_utils_src_fixidity_.md)
      - [packages/sdk/utils/src/future](developer-resources/utils/reference/modules/_packages_sdk_utils_src_future_.md)
      - [packages/sdk/utils/src/inputValidation](developer-resources/utils/reference/modules/_packages_sdk_utils_src_inputvalidation_.md)
      - [packages/sdk/utils/src/io](developer-resources/utils/reference/modules/_packages_sdk_utils_src_io_.md)
      - [packages/sdk/utils/src/istanbul](developer-resources/utils/reference/modules/_packages_sdk_utils_src_istanbul_.md)
      - [IstanbulExtra](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_istanbul_.istanbulextra.md)
      - [Seal](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_istanbul_.seal.md)
      - [packages/sdk/utils/src/logger](developer-resources/utils/reference/modules/_packages_sdk_utils_src_logger_.md)
      - [packages/sdk/utils/src/parsing](developer-resources/utils/reference/modules/_packages_sdk_utils_src_parsing_.md)
      - [packages/sdk/utils/src/phoneNumbers](developer-resources/utils/reference/modules/_packages_sdk_utils_src_phonenumbers_.md)
      - [packages/sdk/utils/src/sign-typed-data-utils](developer-resources/utils/reference/modules/_packages_sdk_utils_src_sign_typed_data_utils_.md)
      - [EIP712Object](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_sign_typed_data_utils_.eip712object.md)
      - [EIP712Parameter](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_sign_typed_data_utils_.eip712parameter.md)
      - [EIP712TypedData](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_sign_typed_data_utils_.eip712typeddata.md)
      - [EIP712Types](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_sign_typed_data_utils_.eip712types.md)
      - [packages/sdk/utils/src/signatureUtils](developer-resources/utils/reference/modules/_packages_sdk_utils_src_signatureutils_.md)
      - [packages/sdk/utils/src/solidity](developer-resources/utils/reference/modules/_packages_sdk_utils_src_solidity_.md)
      - [packages/sdk/utils/src/string](developer-resources/utils/reference/modules/_packages_sdk_utils_src_string_.md)
      - [packages/sdk/utils/src/task](developer-resources/utils/reference/modules/_packages_sdk_utils_src_task_.md)
      - [packages/sdk/utils/src/typed-data-constructors](developer-resources/utils/reference/modules/_packages_sdk_utils_src_typed_data_constructors_.md)
    - [Classes]()
      - [F](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_f_.f.md)
      - [F2](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_f2_.f2.md)
      - [G1](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_g1_.g1.md)
      - [G2](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_g2_.g2.md)
      - [Group](developer-resources/utils/reference/classes/_node_modules_bls12377js_src_group_.group.md)
      - [Countries](developer-resources/utils/reference/classes/_packages_sdk_utils_src_countries_.countries.md)
    - [Enums]()
      - [DappKitRequestTypes](developer-resources/utils/reference/enums/_packages_sdk_utils_src_dappkit_.dappkitrequesttypes.md)
      - [DappKitResponseStatus](developer-resources/utils/reference/enums/_packages_sdk_utils_src_dappkit_.dappkitresponsestatus.md)
    - [Interfaces]()
      - [FieldSpec](developer-resources/utils/reference/interfaces/_node_modules_bls12377js_src_defs_.fieldspec.md)
      - [GroupSpec](developer-resources/utils/reference/interfaces/_node_modules_bls12377js_src_defs_.groupspec.md)
      - [EncryptionStatus](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_commentencryption_.encryptionstatus.md)
      - [LocalizedCountry](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_countries_.localizedcountry.md)
      - [AccountAuthRequest](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.accountauthrequest.md)
      - [AccountAuthResponseFailure](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.accountauthresponsefailure.md)
      - [AccountAuthResponseSuccess](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.accountauthresponsesuccess.md)
      - [DappKitRequestBase](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.dappkitrequestbase.md)
      - [DappKitRequestMeta](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.dappkitrequestmeta.md)
      - [SignTxRequest](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.signtxrequest.md)
      - [SignTxResponseFailure](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.signtxresponsefailure.md)
      - [SignTxResponseSuccess](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.signtxresponsesuccess.md)
      - [TxToSignParam](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_dappkit_.txtosignparam.md)
      - [IstanbulExtra](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_istanbul_.istanbulextra.md)
      - [Seal](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_istanbul_.seal.md)
      - [EIP712Object](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_sign_typed_data_utils_.eip712object.md)
      - [EIP712Parameter](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_sign_typed_data_utils_.eip712parameter.md)
      - [EIP712TypedData](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_sign_typed_data_utils_.eip712typeddata.md)
      - [EIP712Types](developer-resources/utils/reference/interfaces/_packages_sdk_utils_src_sign_typed_data_utils_.eip712types.md)
    <!-- utils-reference-end -->

  - [Wallet-Base](developer-resources/wallet-base/reference/SUMMARY.md)
    <!-- wallet-base-reference-start -->
    - [Globals](developer-resources/wallet-base/reference/globals.md)
    - [Modules]()
      - [signing-utils](developer-resources/wallet-base/reference/modules/_signing_utils_.md)
      - [wallet-base](developer-resources/wallet-base/reference/modules/_wallet_base_.md)
      - [WalletBase](developer-resources/wallet-base/reference/classes/_wallet_base_.walletbase.md)
      - [UnlockableWallet](developer-resources/wallet-base/reference/interfaces/_wallet_base_.unlockablewallet.md)
      - [Wallet](developer-resources/wallet-base/reference/interfaces/_wallet_base_.wallet.md)
    - [Classes]()
      - [WalletBase](developer-resources/wallet-base/reference/classes/_wallet_base_.walletbase.md)
    - [Interfaces]()
      - [UnlockableWallet](developer-resources/wallet-base/reference/interfaces/_wallet_base_.unlockablewallet.md)
      - [Wallet](developer-resources/wallet-base/reference/interfaces/_wallet_base_.wallet.md)
    <!-- wallet-base-reference-end -->

  - [Wallet-Hsm](developer-resources/wallet-hsm/reference/SUMMARY.md)
    <!-- wallet-hsm-reference-start -->
    - [Globals](developer-resources/wallet-hsm/reference/globals.md)
    - [Modules]()
      - [ber-utils](developer-resources/wallet-hsm/reference/modules/_ber_utils_.md)
      - [signature-utils](developer-resources/wallet-hsm/reference/modules/_signature_utils_.md)
      - [Signature](developer-resources/wallet-hsm/reference/classes/_signature_utils_.signature.md)
    - [Classes]()
      - [Signature](developer-resources/wallet-hsm/reference/classes/_signature_utils_.signature.md)
    <!-- wallet-hsm-reference-end -->

  - [Wallet-Hsm-Aws](developer-resources/wallet-hsm-aws/reference/SUMMARY.md)
    <!-- wallet-hsm-aws-reference-start -->
    - [Globals](developer-resources/wallet-hsm-aws/reference/globals.md)
    - [Modules]()
      - [aws-hsm-signer](developer-resources/wallet-hsm-aws/reference/modules/_aws_hsm_signer_.md)
      - [AwsHsmSigner](developer-resources/wallet-hsm-aws/reference/classes/_aws_hsm_signer_.awshsmsigner.md)
      - [aws-hsm-wallet](developer-resources/wallet-hsm-aws/reference/modules/_aws_hsm_wallet_.md)
      - [AwsHsmWallet](developer-resources/wallet-hsm-aws/reference/classes/_aws_hsm_wallet_.awshsmwallet.md)
    - [Classes]()
      - [AwsHsmSigner](developer-resources/wallet-hsm-aws/reference/classes/_aws_hsm_signer_.awshsmsigner.md)
      - [AwsHsmWallet](developer-resources/wallet-hsm-aws/reference/classes/_aws_hsm_wallet_.awshsmwallet.md)
    <!-- wallet-hsm-aws-reference-end -->

  - [Wallet-Hsm-Azure](developer-resources/wallet-hsm-azure/reference/SUMMARY.md)
    <!-- wallet-hsm-azure-reference-start -->
    - [Globals](developer-resources/wallet-hsm-azure/reference/globals.md)
    - [Modules]()
      - [azure-hsm-signer](developer-resources/wallet-hsm-azure/reference/modules/_azure_hsm_signer_.md)
      - [AzureHSMSigner](developer-resources/wallet-hsm-azure/reference/classes/_azure_hsm_signer_.azurehsmsigner.md)
      - [azure-hsm-wallet](developer-resources/wallet-hsm-azure/reference/modules/_azure_hsm_wallet_.md)
      - [AzureHSMWallet](developer-resources/wallet-hsm-azure/reference/classes/_azure_hsm_wallet_.azurehsmwallet.md)
      - [azure-key-vault-client](developer-resources/wallet-hsm-azure/reference/modules/_azure_key_vault_client_.md)
      - [AzureKeyVaultClient](developer-resources/wallet-hsm-azure/reference/classes/_azure_key_vault_client_.azurekeyvaultclient.md)
    - [Classes]()
      - [AzureHSMSigner](developer-resources/wallet-hsm-azure/reference/classes/_azure_hsm_signer_.azurehsmsigner.md)
      - [AzureHSMWallet](developer-resources/wallet-hsm-azure/reference/classes/_azure_hsm_wallet_.azurehsmwallet.md)
      - [AzureKeyVaultClient](developer-resources/wallet-hsm-azure/reference/classes/_azure_key_vault_client_.azurekeyvaultclient.md)
    <!-- wallet-hsm-azure-reference-end -->

  - [Wallet-Ledger](developer-resources/wallet-ledger/reference/SUMMARY.md)
    <!-- wallet-ledger-reference-start -->
    - [Globals](developer-resources/wallet-ledger/reference/globals.md)
    - [Modules]()
      - [data](developer-resources/wallet-ledger/reference/modules/_data_.md)
      - [ledger-signer](developer-resources/wallet-ledger/reference/modules/_ledger_signer_.md)
      - [LedgerSigner](developer-resources/wallet-ledger/reference/classes/_ledger_signer_.ledgersigner.md)
      - [ledger-utils](developer-resources/wallet-ledger/reference/modules/_ledger_utils_.md)
      - [ledger-wallet](developer-resources/wallet-ledger/reference/modules/_ledger_wallet_.md)
      - [AddressValidation](developer-resources/wallet-ledger/reference/enums/_ledger_wallet_.addressvalidation.md)
      - [LedgerWallet](developer-resources/wallet-ledger/reference/classes/_ledger_wallet_.ledgerwallet.md)
      - [tokens](developer-resources/wallet-ledger/reference/modules/_tokens_.md)
      - [API](developer-resources/wallet-ledger/reference/interfaces/_tokens_.api.md)
      - [TokenInfo](developer-resources/wallet-ledger/reference/interfaces/_tokens_.tokeninfo.md)
    - [Classes]()
      - [LedgerSigner](developer-resources/wallet-ledger/reference/classes/_ledger_signer_.ledgersigner.md)
      - [LedgerWallet](developer-resources/wallet-ledger/reference/classes/_ledger_wallet_.ledgerwallet.md)
    - [Enums]()
      - [AddressValidation](developer-resources/wallet-ledger/reference/enums/_ledger_wallet_.addressvalidation.md)
    - [Interfaces]()
      - [API](developer-resources/wallet-ledger/reference/interfaces/_tokens_.api.md)
      - [TokenInfo](developer-resources/wallet-ledger/reference/interfaces/_tokens_.tokeninfo.md)
    <!-- wallet-ledger-reference-end -->

  - [Wallet-Local](developer-resources/wallet-local/reference/SUMMARY.md)
    <!-- wallet-local-reference-start -->
    - [Globals](developer-resources/wallet-local/reference/globals.md)
    - [Modules]()
      - [local-signer](developer-resources/wallet-local/reference/modules/_local_signer_.md)
      - [LocalSigner](developer-resources/wallet-local/reference/classes/_local_signer_.localsigner.md)
      - [local-wallet](developer-resources/wallet-local/reference/modules/_local_wallet_.md)
      - [LocalWallet](developer-resources/wallet-local/reference/classes/_local_wallet_.localwallet.md)
    - [Classes]()
      - [LocalSigner](developer-resources/wallet-local/reference/classes/_local_signer_.localsigner.md)
      - [LocalWallet](developer-resources/wallet-local/reference/classes/_local_wallet_.localwallet.md)
    <!-- wallet-local-reference-end -->

  - [Wallet-Remote](developer-resources/wallet-remote/reference/SUMMARY.md)
    <!-- wallet-remote-reference-start -->
    - [Globals](developer-resources/wallet-remote/reference/globals.md)
    - [Modules]()
      - [remote-wallet](developer-resources/wallet-remote/reference/modules/_remote_wallet_.md)
      - [RemoteWallet](developer-resources/wallet-remote/reference/classes/_remote_wallet_.remotewallet.md)
    - [Classes]()
      - [RemoteWallet](developer-resources/wallet-remote/reference/classes/_remote_wallet_.remotewallet.md)
    <!-- wallet-remote-reference-end -->

  - [Wallet-Rpc](developer-resources/wallet-rpc/reference/SUMMARY.md)
    <!-- wallet-rpc-reference-start -->
    - [Globals](developer-resources/wallet-rpc/reference/globals.md)
    - [Modules]()
      - [rpc-signer](developer-resources/wallet-rpc/reference/modules/_rpc_signer_.md)
      - [RpcSigner](developer-resources/wallet-rpc/reference/classes/_rpc_signer_.rpcsigner.md)
      - [rpc-wallet](developer-resources/wallet-rpc/reference/modules/_rpc_wallet_.md)
      - [RpcWalletErrors](developer-resources/wallet-rpc/reference/enums/_rpc_wallet_.rpcwalleterrors.md)
      - [RpcWallet](developer-resources/wallet-rpc/reference/classes/_rpc_wallet_.rpcwallet.md)
      - [test-utils/ganache.setup](developer-resources/wallet-rpc/reference/modules/_test_utils_ganache_setup_.md)
      - [test-utils/ganache.teardown](developer-resources/wallet-rpc/reference/modules/_test_utils_ganache_teardown_.md)
    - [Classes]()
      - [RpcSigner](developer-resources/wallet-rpc/reference/classes/_rpc_signer_.rpcsigner.md)
      - [RpcWallet](developer-resources/wallet-rpc/reference/classes/_rpc_wallet_.rpcwallet.md)
    - [Enums]()
      - [RpcWalletErrors](developer-resources/wallet-rpc/reference/enums/_rpc_wallet_.rpcwalleterrors.md)
    <!-- wallet-rpc-reference-end -->


## Celo Codebase

- [Celo Protocol](celo-codebase/protocol/README.md)
  - [Consensus](celo-codebase/protocol/consensus/README.md)
    - [Validator Set Differences](celo-codebase/protocol/consensus/validator-set-differences.md)
    - [Locating Nodes](celo-codebase/protocol/consensus/locating-nodes.md)
    - [Ultralight Sync](celo-codebase/protocol/consensus/ultralight-sync.md)
  - [Proof-of-Stake](celo-codebase/protocol/proof-of-stake/README.md)
    - [Validator Groups](celo-codebase/protocol/proof-of-stake/validator-groups.md)
    - [Locked Gold and Voting](celo-codebase/protocol/proof-of-stake/locked-gold.md)
    - [Validator Elections](celo-codebase/protocol/proof-of-stake/validator-elections.md)
    - [Epoch Rewards](celo-codebase/protocol/proof-of-stake/epoch-rewards.md)
      - [Rewards for Validators and Validator Groups](celo-codebase/protocol/proof-of-stake/validator-rewards.md)
      - [Rewards for Locked Gold Holders](celo-codebase/protocol/proof-of-stake/locked-gold-rewards.md)
      - [Community Fund](celo-codebase/protocol/proof-of-stake/community-fund.md)
      - [Carbon Offsetting Fund](celo-codebase/protocol/proof-of-stake/carbon-offsetting-fund.md)
    - [Penalties](celo-codebase/protocol/proof-of-stake/penalties.md)
  - [Governance](celo-codebase/protocol/governance.md)
  - [Stability Mechanism](celo-codebase/protocol/stability/README.md)
    - [Stability Algorithm \(CP-DOTO\)](celo-codebase/protocol/stability/doto.md)
    - [Oracles](celo-codebase/protocol/stability/oracles.md)
    - [Stability Fees](celo-codebase/protocol/stability/stability-fees.md)
    - [Tobin Tax](celo-codebase/protocol/stability/tobin-tax.md)
  - [Transactions](celo-codebase/protocol/transactions/README.md)
    - [Native Currency](celo-codebase/protocol/transactions/native-currency.md)
    - [Paying for Gas in Tokens](celo-codebase/protocol/transactions/erc20-transaction-fees.md)
    - [Gas Pricing](celo-codebase/protocol/transactions/gas-pricing.md)
    - [Escrow](celo-codebase/protocol/transactions/escrow.md)
    - [Encrypted Payment Comments](celo-codebase/protocol/transactions/tx-comment-encyption.md)
    - [Full Node Incentives](celo-codebase/protocol/transactions/full-node-incentives.md)
  - [Identity](celo-codebase/protocol/identity/README.md)
    - [Phone Number Privacy](celo-codebase/protocol/identity/phone-number-privacy.md)
    - [Metadata](celo-codebase/protocol/identity/metadata.md)
    - [Randomness](celo-codebase/protocol/identity/randomness.md)
  - [Plumo Ultralight Sync](celo-codebase/protocol/plumo.md)
- [Celo Wallet](celo-codebase/wallet/README.md)
  - [Running the Wallet Locally](celo-codebase/wallet/intro.md)
  - [Wallet Functionality](celo-codebase/wallet/how-the-wallet-works/README.md)
    - [Verification](celo-codebase/wallet/how-the-wallet-works/verification.md)
    - [Invitations](celo-codebase/wallet/how-the-wallet-works/invitations.md)
    - [Payments and Exchanging](celo-codebase/wallet/how-the-wallet-works/sending-and-requesting-payments.md)
    - [Ultralight Node Sync](celo-codebase/wallet/how-the-wallet-works/ultralight-node-sync.md)

## Command Line Interface

- [Introduction](command-line-interface/introduction.md)
- [Commands](command-line-interface/commands.md)
  - [Account](command-line-interface/account.md)
  - [Config](command-line-interface/config.md)
  - [DKG](command-line-interface/dkg.md)
  - [Election](command-line-interface/election.md)
  - [Exchange](command-line-interface/exchange.md)
  - [Governance](command-line-interface/governance.md)
  - [Identity](command-line-interface/identity.md)
  - [LockedGold](command-line-interface/lockedgold.md)
  - [Multisig](command-line-interface/multisig.md)
  - [Network](command-line-interface/network.md)
  - [Node](command-line-interface/node.md)
  - [Oracle](command-line-interface/oracle.md)
  - [ReleaseGold](command-line-interface/releasegold.md)
  - [Reserve](command-line-interface/reserve.md)
  - [Rewards](command-line-interface/rewards.md)
  - [Transfer](command-line-interface/transfer.md)
  - [Validator](command-line-interface/validator.md)
  - [ValidatorGroup](command-line-interface/validatorgroup.md)
  - [Help](command-line-interface/help.md)

## Community

- [Code of Conduct](community/code-of-conduct.md)
- [Contributing](community/contributing.md)
- [Grant Playbook](community/grant-playbook.md)
- [Release Process](community/release-process/README.md)
  - [Smart Contracts](community/release-process/smart-contracts.md)
  - [Blockchain Client](community/release-process/blockchain-client.md)
  - [Celocli and ContractKit](community/release-process/base-cli-contractkit-dappkit-utils.md)
  - [Attestation Service](community/release-process/attestation-service.md)

## Important Information

- [Alfajores Testnet Disclaimer](important-information/alfajores-testnet-disclaimer.md)
- [Baklava Testnet Disclaimer](important-information/baklava-testnet-disclaimer.md)
- [Mainnet Disclaimer](important-information/mainnet-network-disclaimer.md)
